const path = require("path");
const CopyWebpackPlugin = require("copy-webpack-plugin");

let copyWebpack_main = new CopyWebpackPlugin({
    patterns: [
        {
            from: "package.json",
            to: "./",
            context: "./src",
        },
    ],
});

let copyWebpack_renderer = new CopyWebpackPlugin({
    patterns: [
        {
            from: "./**/*.{html,css}",
            to: "./renderer",
            context: "./src/renderer",
        }, {
            from: "./**/*",
            to: "./renderer/contrib",
            context: "./src/renderer/contrib",
        }
    ],
});

let babel_transpile = {
    loader: 'babel-loader',
    options: {
        presets: ['@babel/preset-env',],
        plugins: ['@babel/plugin-proposal-class-properties',]
    }
}

let forMain = {
    target: "electron-main",
    mode: "development",
    entry: {"main/main": "./src/main/main.js"},
    output: {path: path.resolve(__dirname, "dist"), filename: "[name].js"},
    module: {rules: [{test: /\.js$/, use: [babel_transpile]}]},
    plugins: [copyWebpack_main]
};

let forRenderer = {
    target: "electron-renderer",
    mode: "development",
    entry: {"renderer/renderer": "./src/renderer/renderer.js"},
    output: {path: path.resolve(__dirname, "dist"), filename: "[name].js"},
    module: {rules: [{test: /\.js$/, use: [babel_transpile]}]},
    plugins: [copyWebpack_renderer]
}

module.exports = () => {
    return [forMain,forRenderer];
}